/*     */ package org.apache.batik.xml;
/*     */ 
/*     */ import java.io.ByteArrayInputStream;
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.io.InputStreamReader;
/*     */ import java.io.PushbackInputStream;
/*     */ import java.io.Reader;
/*     */ import org.apache.batik.util.EncodingUtilities;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class XMLUtilities
/*     */   extends XMLCharacters
/*     */ {
/*  49 */   public static boolean isXMLSpace(char c) { return (c <= ' ' && (4294977024L >> c & 0x1L) != 0L); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  61 */   public static boolean isXMLNameFirstCharacter(char c) { return ((XMLCharacters.NAME_FIRST_CHARACTER[c / ' '] & '\001' << c % ' ') != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  69 */   public static boolean isXML11NameFirstCharacter(char c) { return ((XMLCharacters.NAME11_FIRST_CHARACTER[c / ' '] & '\001' << c % ' ') != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  76 */   public static boolean isXMLNameCharacter(char c) { return ((XMLCharacters.NAME_CHARACTER[c / ' '] & '\001' << c % ' ') != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  83 */   public static boolean isXML11NameCharacter(char c) { return ((XMLCharacters.NAME11_CHARACTER[c / ' '] & '\001' << c % ' ') != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  94 */   public static boolean isXMLCharacter(int c) { return ((XMLCharacters.XML_CHARACTER[c >>> 5] & 1 << (c & 0x1F)) != 0 || (c >= 65536 && c <= 1114111)); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 102 */   public static boolean isXML11Character(int c) { return ((c >= 1 && c <= 55295) || (c >= 57344 && c <= 65533) || (c >= 65536 && c <= 1114111)); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 111 */   public static boolean isXMLPublicIdCharacter(char c) { return (c < '' && (XMLCharacters.PUBLIC_ID_CHARACTER[c / ' '] & '\001' << c % ' ') != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 119 */   public static boolean isXMLVersionCharacter(char c) { return (c < '' && (XMLCharacters.VERSION_CHARACTER[c / ' '] & '\001' << c % ' ') != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 127 */   public static boolean isXMLAlphabeticCharacter(char c) { return (c < '' && (XMLCharacters.ALPHABETIC_CHARACTER[c / ' '] & '\001' << c % ' ') != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Reader createXMLDocumentReader(InputStream is) throws IOException {
/* 144 */     PushbackInputStream pbis = new PushbackInputStream(is, 128);
/* 145 */     byte[] buf = new byte[4];
/*     */     
/* 147 */     int len = pbis.read(buf);
/* 148 */     if (len > 0) {
/* 149 */       pbis.unread(buf, 0, len);
/*     */     }
/*     */     
/* 152 */     if (len == 4) {
/* 153 */       switch (buf[0] & 0xFF) {
/*     */         case 0:
/* 155 */           if (buf[1] == 60 && buf[2] == 0 && buf[3] == 63) {
/* 156 */             return new InputStreamReader(pbis, "UnicodeBig");
/*     */           }
/*     */           break;
/*     */         
/*     */         case 60:
/* 161 */           switch (buf[1] & 0xFF) {
/*     */             case 0:
/* 163 */               if (buf[2] == 63 && buf[3] == 0) {
/* 164 */                 return new InputStreamReader(pbis, "UnicodeLittle");
/*     */               }
/*     */               break;
/*     */             
/*     */             case 63:
/* 169 */               if (buf[2] == 120 && buf[3] == 109) {
/* 170 */                 Reader r = createXMLDeclarationReader(pbis, "UTF8");
/* 171 */                 String enc = getXMLDeclarationEncoding(r, "UTF8");
/* 172 */                 return new InputStreamReader(pbis, enc);
/*     */               } 
/*     */               break;
/*     */           } 
/*     */           break;
/*     */         case 76:
/* 178 */           if (buf[1] == 111 && (buf[2] & 0xFF) == 167 && (buf[3] & 0xFF) == 148) {
/*     */ 
/*     */             
/* 181 */             Reader r = createXMLDeclarationReader(pbis, "CP037");
/* 182 */             String enc = getXMLDeclarationEncoding(r, "CP037");
/* 183 */             return new InputStreamReader(pbis, enc);
/*     */           } 
/*     */           break;
/*     */         
/*     */         case 254:
/* 188 */           if ((buf[1] & 0xFF) == 255) {
/* 189 */             return new InputStreamReader(pbis, "Unicode");
/*     */           }
/*     */           break;
/*     */         
/*     */         case 255:
/* 194 */           if ((buf[1] & 0xFF) == 254) {
/* 195 */             return new InputStreamReader(pbis, "Unicode");
/*     */           }
/*     */           break;
/*     */       } 
/*     */     }
/* 200 */     return new InputStreamReader(pbis, "UTF8");
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static Reader createXMLDeclarationReader(PushbackInputStream pbis, String enc) throws IOException {
/* 212 */     byte[] buf = new byte[128];
/* 213 */     int len = pbis.read(buf);
/*     */     
/* 215 */     if (len > 0) {
/* 216 */       pbis.unread(buf, 0, len);
/*     */     }
/*     */     
/* 219 */     return new InputStreamReader(new ByteArrayInputStream(buf, 4, len), enc);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static String getXMLDeclarationEncoding(Reader r, String e) throws IOException {
/*     */     int c;
/* 231 */     if ((c = r.read()) != 108) {
/* 232 */       return e;
/*     */     }
/*     */     
/* 235 */     if (!isXMLSpace((char)(c = r.read())))
/* 236 */       return e; 
/*     */     do {
/*     */     
/* 239 */     } while (isXMLSpace((char)(c = r.read())));
/*     */     
/* 241 */     if (c != 118) {
/* 242 */       return e;
/*     */     }
/* 244 */     if ((c = r.read()) != 101) {
/* 245 */       return e;
/*     */     }
/* 247 */     if ((c = r.read()) != 114) {
/* 248 */       return e;
/*     */     }
/* 250 */     if ((c = r.read()) != 115) {
/* 251 */       return e;
/*     */     }
/* 253 */     if ((c = r.read()) != 105) {
/* 254 */       return e;
/*     */     }
/* 256 */     if ((c = r.read()) != 111) {
/* 257 */       return e;
/*     */     }
/* 259 */     if ((c = r.read()) != 110) {
/* 260 */       return e;
/*     */     }
/*     */     
/* 263 */     c = r.read();
/* 264 */     while (isXMLSpace((char)c)) {
/* 265 */       c = r.read();
/*     */     }
/*     */     
/* 268 */     if (c != 61)
/* 269 */       return e; 
/*     */     do {
/*     */     
/* 272 */     } while (isXMLSpace((char)(c = r.read())));
/*     */     
/* 274 */     if (c != 34 && c != 39) {
/* 275 */       return e;
/*     */     }
/* 277 */     char sc = (char)c;
/*     */     
/*     */     while (true) {
/* 280 */       c = r.read();
/* 281 */       if (c == sc) {
/*     */         break;
/*     */       }
/* 284 */       if (!isXMLVersionCharacter((char)c)) {
/* 285 */         return e;
/*     */       }
/*     */     } 
/*     */     
/* 289 */     if (!isXMLSpace((char)(c = r.read())))
/* 290 */       return e;  do {
/*     */     
/* 292 */     } while (isXMLSpace((char)(c = r.read())));
/*     */     
/* 294 */     if (c != 101) {
/* 295 */       return e;
/*     */     }
/* 297 */     if ((c = r.read()) != 110) {
/* 298 */       return e;
/*     */     }
/* 300 */     if ((c = r.read()) != 99) {
/* 301 */       return e;
/*     */     }
/* 303 */     if ((c = r.read()) != 111) {
/* 304 */       return e;
/*     */     }
/* 306 */     if ((c = r.read()) != 100) {
/* 307 */       return e;
/*     */     }
/* 309 */     if ((c = r.read()) != 105) {
/* 310 */       return e;
/*     */     }
/* 312 */     if ((c = r.read()) != 110) {
/* 313 */       return e;
/*     */     }
/* 315 */     if ((c = r.read()) != 103) {
/* 316 */       return e;
/*     */     }
/*     */     
/* 319 */     c = r.read();
/* 320 */     while (isXMLSpace((char)c)) {
/* 321 */       c = r.read();
/*     */     }
/*     */     
/* 324 */     if (c != 61)
/* 325 */       return e; 
/*     */     do {
/*     */     
/* 328 */     } while (isXMLSpace((char)(c = r.read())));
/*     */     
/* 330 */     if (c != 34 && c != 39) {
/* 331 */       return e;
/*     */     }
/* 333 */     sc = (char)c;
/*     */     
/* 335 */     StringBuffer enc = new StringBuffer();
/*     */     while (true) {
/* 337 */       c = r.read();
/* 338 */       if (c == -1) {
/* 339 */         return e;
/*     */       }
/* 341 */       if (c == sc) {
/* 342 */         return encodingToJavaEncoding(enc.toString(), e);
/*     */       }
/* 344 */       enc.append((char)c);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static String encodingToJavaEncoding(String e, String de) {
/* 355 */     String result = EncodingUtilities.javaEncoding(e);
/* 356 */     return (result == null) ? de : result;
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-xml.jar!\org\apache\batik\xml\XMLUtilities.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */